import { ServiceBroker } from 'moleculer';
import type { CdmLogger } from '@cdm-logger/core';
import { BaseProxyService } from '@common-stack/store-mongo';
import { IAccountServiceContext, IOrgOnBoardingParamsInput, MoleculerServiceName, TokenTypesEnum, IUpdateProfileInput, IUpdateUserAccountAliasesInput, IUserAccount, IUserAccountCreateRequest, IUserAccountLoginHistory, IUserAccountLoginHistorySystem, IUserAccountRemoveRequest, IUserAccountUpdateRequest, IUserAccountWhere, IUserAuth0UpdateFields, IUserProfile, IUsersToken, IUserToken, IAccountService, FilterCriteria, AsDomainType, IUserAccountModel } from 'common/server';
export declare class AccountProxyService extends BaseProxyService<AsDomainType<IUserAccountModel>> implements IAccountService {
    protected logger?: CdmLogger.ILogger;
    protected topic: MoleculerServiceName;
    constructor(broker: ServiceBroker, logger: CdmLogger.ILogger);
    getUserTokens(userId: string, tokenType: TokenTypesEnum[]): Promise<IUserToken[]>;
    dispatchUserVerificationEmail(email: string, emailVerificationToken: IUserToken): Promise<void>;
    dispatchUserPasswordResetEmail(user: IUserAccount, token: string): Promise<void>;
    createDefaultAccount(user: any, context?: IAccountServiceContext): Promise<AsDomainType<IUserAccountModel>>;
    updateUserAccount(user: IUserProfile, userInfo: IUserAuth0UpdateFields): Promise<AsDomainType<IUserAccountModel>>;
    updateUserAccountAliases(input: IUpdateUserAccountAliasesInput): Promise<AsDomainType<IUserAccountModel>>;
    createAccount(account: IUserAccountCreateRequest): Promise<AsDomainType<IUserAccountModel>>;
    findAccountById(id: string): Promise<AsDomainType<IUserAccountModel> | Error>;
    findAccountByUser(id: string, context: IAccountServiceContext): Promise<AsDomainType<IUserAccountModel> | Error>;
    findAccountByEmail(email: string): Promise<AsDomainType<IUserAccountModel> | Error>;
    getUsers(where: IUserAccountWhere): Promise<AsDomainType<IUserAccountModel>[]>;
    updateAccount(account: IUserAccountUpdateRequest): Promise<AsDomainType<IUserAccountModel>>;
    deleteAccount(account: IUserAccountRemoveRequest): Promise<boolean>;
    accountOnBoarding(input: IOrgOnBoardingParamsInput, context?: any): Promise<boolean>;
    deleteUserAccount(id: string): Promise<boolean>;
    getUserTokenDetails(userId: string, type: TokenTypesEnum): Promise<AsDomainType<IUserToken>>;
    addUserToken(userId: string, token: IUserToken): Promise<boolean>;
    removeUserToken(userId: string, token: IUserToken): Promise<boolean>;
    getAllUserTokens(userIds: string[], tokenTypes: TokenTypesEnum[]): Promise<IUsersToken[]>;
    getUserAccountByEmail(email: string): Promise<AsDomainType<IUserAccountModel>>;
    getAccountsLoginRecords(skip: number, limit: number): Promise<IUserAccountLoginHistory[]>;
    addAccountLoginHistoryRecord(args: {
        accountId: string;
        ipAddress: string;
        system: IUserAccountLoginHistorySystem;
    }): Promise<boolean>;
    updateUserProfile(account: IUpdateProfileInput, context?: IAccountServiceContext): Promise<boolean>;
    bulkDelete(criteria: FilterCriteria<IUserAccount>): Promise<number>;
}
